This directory contains the schema files for the Beacon model(s).

The schemas are edited in the `src` directories and exported into `json` representation using `./bin/yamlerRunner.sh`.

The JSON versions of the files serves as the default / referenceable version of the schemas.
